# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .list_meta import ListMeta
from .attachment_response import AttachmentResponse

__all__ = ["AttachmentListResponse"]


class AttachmentListResponse(BaseModel):
    meta: Optional[ListMeta] = None

    objects: Optional[List[AttachmentResponse]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["TemplateListParams"]


class TemplateListParams(TypedDict, total=False):
    archive: str

    group: str
    """can be full resource_uri or only id"""

    limit: int
    """Length of dataset to return. Use with offset query to iterate through results."""

    offset: int
    """Offset from start of dataset.

    Use with the limit query to iterate through dataset.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import WebhookEventFilterEnum, unsubscribe_delete_webhook_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.webhook_event_filter_enum import WebhookEventFilterEnum

__all__ = ["UnsubscribeResource", "AsyncUnsubscribeResource"]


class UnsubscribeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UnsubscribeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return UnsubscribeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UnsubscribeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return UnsubscribeResourceWithStreamingResponse(self)

    def delete_webhook(
        self,
        *,
        url: str,
        event_filter: WebhookEventFilterEnum | Omit = omit,
        group: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete webhook

        Args:
          url: URL to remove, it must match any registered callback exactly

          group: if a group filter is applied refer to it with slug or resource_uri

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/unsubscribe/",
            body=maybe_transform(
                {
                    "url": url,
                    "event_filter": event_filter,
                    "group": group,
                },
                unsubscribe_delete_webhook_params.UnsubscribeDeleteWebhookParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncUnsubscribeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUnsubscribeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUnsubscribeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUnsubscribeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncUnsubscribeResourceWithStreamingResponse(self)

    async def delete_webhook(
        self,
        *,
        url: str,
        event_filter: WebhookEventFilterEnum | Omit = omit,
        group: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete webhook

        Args:
          url: URL to remove, it must match any registered callback exactly

          group: if a group filter is applied refer to it with slug or resource_uri

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/unsubscribe/",
            body=await async_maybe_transform(
                {
                    "url": url,
                    "event_filter": event_filter,
                    "group": group,
                },
                unsubscribe_delete_webhook_params.UnsubscribeDeleteWebhookParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class UnsubscribeResourceWithRawResponse:
    def __init__(self, unsubscribe: UnsubscribeResource) -> None:
        self._unsubscribe = unsubscribe

        self.delete_webhook = to_raw_response_wrapper(
            unsubscribe.delete_webhook,
        )


class AsyncUnsubscribeResourceWithRawResponse:
    def __init__(self, unsubscribe: AsyncUnsubscribeResource) -> None:
        self._unsubscribe = unsubscribe

        self.delete_webhook = async_to_raw_response_wrapper(
            unsubscribe.delete_webhook,
        )


class UnsubscribeResourceWithStreamingResponse:
    def __init__(self, unsubscribe: UnsubscribeResource) -> None:
        self._unsubscribe = unsubscribe

        self.delete_webhook = to_streamed_response_wrapper(
            unsubscribe.delete_webhook,
        )


class AsyncUnsubscribeResourceWithStreamingResponse:
    def __init__(self, unsubscribe: AsyncUnsubscribeResource) -> None:
        self._unsubscribe = unsubscribe

        self.delete_webhook = async_to_streamed_response_wrapper(
            unsubscribe.delete_webhook,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import TimezoneEnum, user_create_params, user_update_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.timezone_enum import TimezoneEnum
from ..types.user_retrieve_response import UserRetrieveResponse

__all__ = ["UserResource", "AsyncUserResource"]


class UserResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> UserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return UserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return UserResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        email: str,
        first_name: str,
        last_name: str,
        groups: str | Omit = omit,
        password: str | Omit = omit,
        permission: Literal["1", "2", "3", "4", "5", "6"] | Omit = omit,
        timezone: TimezoneEnum | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create user

        Args:
          groups: comma delimited list of groups to add user to, can be full group resource_uri or
              groupId

          password: If not set a verification email is sent. Password must be at least 8 chars,
              include upper and lower case, with a number and a special character

          permission: set user permissions _ 1 - admin _ 2 - create and send docs, team user _ 3 -
              readonly, team user _ 4 - send only, team user _ 5 - send only, individual user
              _ 6 - create and send docs, invidual user

          timezone: List of available timezones

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/user/",
            body=maybe_transform(
                {
                    "email": email,
                    "first_name": first_name,
                    "last_name": last_name,
                    "groups": groups,
                    "password": password,
                    "permission": permission,
                    "timezone": timezone,
                },
                user_create_params.UserCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        user_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserRetrieveResponse:
        """
        Get user

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._get(
            f"/user/{user_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserRetrieveResponse,
        )

    def update(
        self,
        user_id: str,
        *,
        first_name: str | Omit = omit,
        last_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update a user first name or last name

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/user/{user_id}/",
            body=maybe_transform(
                {
                    "first_name": first_name,
                    "last_name": last_name,
                },
                user_update_params.UserUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncUserResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncUserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncUserResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        email: str,
        first_name: str,
        last_name: str,
        groups: str | Omit = omit,
        password: str | Omit = omit,
        permission: Literal["1", "2", "3", "4", "5", "6"] | Omit = omit,
        timezone: TimezoneEnum | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create user

        Args:
          groups: comma delimited list of groups to add user to, can be full group resource_uri or
              groupId

          password: If not set a verification email is sent. Password must be at least 8 chars,
              include upper and lower case, with a number and a special character

          permission: set user permissions _ 1 - admin _ 2 - create and send docs, team user _ 3 -
              readonly, team user _ 4 - send only, team user _ 5 - send only, individual user
              _ 6 - create and send docs, invidual user

          timezone: List of available timezones

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/user/",
            body=await async_maybe_transform(
                {
                    "email": email,
                    "first_name": first_name,
                    "last_name": last_name,
                    "groups": groups,
                    "password": password,
                    "permission": permission,
                    "timezone": timezone,
                },
                user_create_params.UserCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        user_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserRetrieveResponse:
        """
        Get user

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._get(
            f"/user/{user_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserRetrieveResponse,
        )

    async def update(
        self,
        user_id: str,
        *,
        first_name: str | Omit = omit,
        last_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update a user first name or last name

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/user/{user_id}/",
            body=await async_maybe_transform(
                {
                    "first_name": first_name,
                    "last_name": last_name,
                },
                user_update_params.UserUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class UserResourceWithRawResponse:
    def __init__(self, user: UserResource) -> None:
        self._user = user

        self.create = to_raw_response_wrapper(
            user.create,
        )
        self.retrieve = to_raw_response_wrapper(
            user.retrieve,
        )
        self.update = to_raw_response_wrapper(
            user.update,
        )


class AsyncUserResourceWithRawResponse:
    def __init__(self, user: AsyncUserResource) -> None:
        self._user = user

        self.create = async_to_raw_response_wrapper(
            user.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            user.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            user.update,
        )


class UserResourceWithStreamingResponse:
    def __init__(self, user: UserResource) -> None:
        self._user = user

        self.create = to_streamed_response_wrapper(
            user.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            user.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            user.update,
        )


class AsyncUserResourceWithStreamingResponse:
    def __init__(self, user: AsyncUserResource) -> None:
        self._user = user

        self.create = async_to_streamed_response_wrapper(
            user.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            user.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            user.update,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ListMeta"]


class ListMeta(BaseModel):
    limit: Optional[int] = None

    next: Optional[str] = None

    offset: Optional[int] = None

    previous: Optional[str] = None

    total_count: Optional[int] = None
    """total number of objects"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import document_list_params, document_create_params, document_preview_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    to_custom_raw_response_wrapper,
    async_to_streamed_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.document_list_response import DocumentListResponse
from ..types.document_create_response import DocumentCreateResponse
from ..types.document_retrieve_response import DocumentRetrieveResponse
from ..types.document_get_fields_response import DocumentGetFieldsResponse

__all__ = ["DocumentResource", "AsyncDocumentResource"]


class DocumentResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DocumentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return DocumentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DocumentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return DocumentResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        group: str,
        name: str,
        signers: Iterable[document_create_params.Signer],
        append_pdf: bool | Omit = omit,
        auto_archive: bool | Omit = omit,
        cc_emails: str | Omit = omit,
        convert_sender_to_signer: bool | Omit = omit,
        do_email: bool | Omit = omit,
        footer: str | Omit = omit,
        footer_height: int | Omit = omit,
        header: str | Omit = omit,
        header_height: int | Omit = omit,
        pdf_password: str | Omit = omit,
        pdf_password_type: Literal[1, 2] | Omit = omit,
        pdftext: Dict[str, str] | Omit = omit,
        redirect: str | Omit = omit,
        reminders: str | Omit = omit,
        return_signer_links: bool | Omit = omit,
        signature_type: int | Omit = omit,
        signers_in_order: bool | Omit = omit,
        signertext: Dict[str, str] | Omit = omit,
        strict_fields: bool | Omit = omit,
        tag: str | Omit = omit,
        tag1: str | Omit = omit,
        tag2: str | Omit = omit,
        template: str | Omit = omit,
        templatepdf: str | Omit = omit,
        text: str | Omit = omit,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentCreateResponse:
        """
        Create signing document

        Args:
          append_pdf: Append Legalesign validation info to final PDF. If not included uses the group
              default.

          auto_archive: Send to archive soon after signing. Keeps web app clutter free

          cc_emails: Comma delimited string of email addresses that are notified of signing or
              rejection.

          convert_sender_to_signer: If any sender fields are left blank, convert them to fields for the first
              recipient.

          do_email: Use Legalesign email to send notification emails. If false suppresses all
              emails.

          footer: Text doc only. The footer for the final pdf. Use keyword \"default\" to use
              group default footer.

          footer_height: Text based doc only. Pixel height of PDF footer, if used. 1px = 0.025cm

          header: Text based doc only. The header for the final pdf. Use keyword \"default\" to
              use group header footer.

          header_height: Text based doc only. Pixel height of final PDF footer, if used. 1px = 0.025cm

          pdf_password: Set a password. Must be ascii encode-able, you must also set signature_type to 4
              and choose a pdf_password_type.

          pdf_password_type: 1 to store password, 2 for to delete from our records upon final signing.

          pdftext: Assign values to PDF sender fields, use field labels as keys. Requires unique
              fields labels. See also strict_fields.

          redirect: URL to send the signer to after signing (instead of download page). Your URL
              will include query parameters with ID and state information as follows:
              YOUR-URL?signer=[signer_uid]&doc=[doc_id]&group=[group_id]&signer_state=[signer_status]&doc_state=[doc_status]

          reminders: Put 'default' if you wish to use the default reminder schedule in the group (go
              to web app to set default schedule)

          return_signer_links: Return document links for signers in the response BODY.

          signature_type: Use 4 to get your executed PDF Certified. Recommended. Defaults to 1 (uses a
              sha256 hash for document integrity).

          signers_in_order: Notify signers in their order sequence. If false all are notified
              simulataneously.

          signertext: Add custom placeholders to signer fields, using labels as keys in an object (as
              for pdftext). Relies on unique labelling.

          strict_fields: pdftext fails silently for invalid field value, set to true to return an error

          template: Resource URI of text template object. This call must contain either one of the
              attributes text, templatepdf, template.

          templatepdf: Resource URI of templatepdf object. This API call must contain either one of the
              attributes text, templatepdf, template.

          text: Raw html. This API call must contain either one of the attributes text,
              templatepdf, template.

          user: Assign document another user in the group. Defaults to API

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/document/",
            body=maybe_transform(
                {
                    "group": group,
                    "name": name,
                    "signers": signers,
                    "append_pdf": append_pdf,
                    "auto_archive": auto_archive,
                    "cc_emails": cc_emails,
                    "convert_sender_to_signer": convert_sender_to_signer,
                    "do_email": do_email,
                    "footer": footer,
                    "footer_height": footer_height,
                    "header": header,
                    "header_height": header_height,
                    "pdf_password": pdf_password,
                    "pdf_password_type": pdf_password_type,
                    "pdftext": pdftext,
                    "redirect": redirect,
                    "reminders": reminders,
                    "return_signer_links": return_signer_links,
                    "signature_type": signature_type,
                    "signers_in_order": signers_in_order,
                    "signertext": signertext,
                    "strict_fields": strict_fields,
                    "tag": tag,
                    "tag1": tag1,
                    "tag2": tag2,
                    "template": template,
                    "templatepdf": templatepdf,
                    "text": text,
                    "user": user,
                },
                document_create_params.DocumentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentCreateResponse,
        )

    def retrieve(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentRetrieveResponse:
        """
        Get document

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        return self._get(
            f"/document/{doc_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentRetrieveResponse,
        )

    def list(
        self,
        *,
        group: str,
        archived: str | Omit = omit,
        created_gt: Union[str, datetime] | Omit = omit,
        email: str | Omit = omit,
        limit: int | Omit = omit,
        modified_gt: Union[str, datetime] | Omit = omit,
        nosigners: str | Omit = omit,
        offset: int | Omit = omit,
        status: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentListResponse:
        """List (unarchived) signing documents.

        Use /status/ if you need high-level
        information.

        Args:
          group: Filter by a specific group, required.

          archived: Filter on archived status, default is false

          created_gt: Filter for those documents created after a certain time

          email: Filter by signer email

          limit: Length of dataset to return. Use with offset query to iterate through results.

          modified_gt: Filter for those documents modified after a certain time

          nosigners: Add value '1' to remove signers information for a faster query

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          status: Filter on document status

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/document/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "group": group,
                        "archived": archived,
                        "created_gt": created_gt,
                        "email": email,
                        "limit": limit,
                        "modified_gt": modified_gt,
                        "nosigners": nosigners,
                        "offset": offset,
                        "status": status,
                    },
                    document_list_params.DocumentListParams,
                ),
            ),
            cast_to=DocumentListResponse,
        )

    def archive(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete does not remove permanently but sets it with status 40 (removed) and
        archives it.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/document/{doc_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete_permanently(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Permanently deletes data and files.

        You must enable group automated deletion. We
        recommend archiveDocument.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/document/{doc_id}/delete/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def download_audit_log(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """
        Download pdf of audit log

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return self._get(
            f"/document/{doc_id}/auditlog/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )

    def get_fields(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentGetFieldsResponse:
        """
        Get document fields

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        return self._get(
            f"/document/{doc_id}/fields/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentGetFieldsResponse,
        )

    def preview(
        self,
        *,
        group: str | Omit = omit,
        signee_count: int | Omit = omit,
        text: str | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Returns a redirect response (302) with link in the Location header to a one-use
        temporary URL you can redirect to, to see a preview of the signing page. Follow
        the redirect immediately since it expires after a few seconds.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/document/preview/",
            body=maybe_transform(
                {
                    "group": group,
                    "signee_count": signee_count,
                    "text": text,
                    "title": title,
                },
                document_preview_params.DocumentPreviewParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncDocumentResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDocumentResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDocumentResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDocumentResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncDocumentResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        group: str,
        name: str,
        signers: Iterable[document_create_params.Signer],
        append_pdf: bool | Omit = omit,
        auto_archive: bool | Omit = omit,
        cc_emails: str | Omit = omit,
        convert_sender_to_signer: bool | Omit = omit,
        do_email: bool | Omit = omit,
        footer: str | Omit = omit,
        footer_height: int | Omit = omit,
        header: str | Omit = omit,
        header_height: int | Omit = omit,
        pdf_password: str | Omit = omit,
        pdf_password_type: Literal[1, 2] | Omit = omit,
        pdftext: Dict[str, str] | Omit = omit,
        redirect: str | Omit = omit,
        reminders: str | Omit = omit,
        return_signer_links: bool | Omit = omit,
        signature_type: int | Omit = omit,
        signers_in_order: bool | Omit = omit,
        signertext: Dict[str, str] | Omit = omit,
        strict_fields: bool | Omit = omit,
        tag: str | Omit = omit,
        tag1: str | Omit = omit,
        tag2: str | Omit = omit,
        template: str | Omit = omit,
        templatepdf: str | Omit = omit,
        text: str | Omit = omit,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentCreateResponse:
        """
        Create signing document

        Args:
          append_pdf: Append Legalesign validation info to final PDF. If not included uses the group
              default.

          auto_archive: Send to archive soon after signing. Keeps web app clutter free

          cc_emails: Comma delimited string of email addresses that are notified of signing or
              rejection.

          convert_sender_to_signer: If any sender fields are left blank, convert them to fields for the first
              recipient.

          do_email: Use Legalesign email to send notification emails. If false suppresses all
              emails.

          footer: Text doc only. The footer for the final pdf. Use keyword \"default\" to use
              group default footer.

          footer_height: Text based doc only. Pixel height of PDF footer, if used. 1px = 0.025cm

          header: Text based doc only. The header for the final pdf. Use keyword \"default\" to
              use group header footer.

          header_height: Text based doc only. Pixel height of final PDF footer, if used. 1px = 0.025cm

          pdf_password: Set a password. Must be ascii encode-able, you must also set signature_type to 4
              and choose a pdf_password_type.

          pdf_password_type: 1 to store password, 2 for to delete from our records upon final signing.

          pdftext: Assign values to PDF sender fields, use field labels as keys. Requires unique
              fields labels. See also strict_fields.

          redirect: URL to send the signer to after signing (instead of download page). Your URL
              will include query parameters with ID and state information as follows:
              YOUR-URL?signer=[signer_uid]&doc=[doc_id]&group=[group_id]&signer_state=[signer_status]&doc_state=[doc_status]

          reminders: Put 'default' if you wish to use the default reminder schedule in the group (go
              to web app to set default schedule)

          return_signer_links: Return document links for signers in the response BODY.

          signature_type: Use 4 to get your executed PDF Certified. Recommended. Defaults to 1 (uses a
              sha256 hash for document integrity).

          signers_in_order: Notify signers in their order sequence. If false all are notified
              simulataneously.

          signertext: Add custom placeholders to signer fields, using labels as keys in an object (as
              for pdftext). Relies on unique labelling.

          strict_fields: pdftext fails silently for invalid field value, set to true to return an error

          template: Resource URI of text template object. This call must contain either one of the
              attributes text, templatepdf, template.

          templatepdf: Resource URI of templatepdf object. This API call must contain either one of the
              attributes text, templatepdf, template.

          text: Raw html. This API call must contain either one of the attributes text,
              templatepdf, template.

          user: Assign document another user in the group. Defaults to API

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/document/",
            body=await async_maybe_transform(
                {
                    "group": group,
                    "name": name,
                    "signers": signers,
                    "append_pdf": append_pdf,
                    "auto_archive": auto_archive,
                    "cc_emails": cc_emails,
                    "convert_sender_to_signer": convert_sender_to_signer,
                    "do_email": do_email,
                    "footer": footer,
                    "footer_height": footer_height,
                    "header": header,
                    "header_height": header_height,
                    "pdf_password": pdf_password,
                    "pdf_password_type": pdf_password_type,
                    "pdftext": pdftext,
                    "redirect": redirect,
                    "reminders": reminders,
                    "return_signer_links": return_signer_links,
                    "signature_type": signature_type,
                    "signers_in_order": signers_in_order,
                    "signertext": signertext,
                    "strict_fields": strict_fields,
                    "tag": tag,
                    "tag1": tag1,
                    "tag2": tag2,
                    "template": template,
                    "templatepdf": templatepdf,
                    "text": text,
                    "user": user,
                },
                document_create_params.DocumentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentCreateResponse,
        )

    async def retrieve(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentRetrieveResponse:
        """
        Get document

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        return await self._get(
            f"/document/{doc_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentRetrieveResponse,
        )

    async def list(
        self,
        *,
        group: str,
        archived: str | Omit = omit,
        created_gt: Union[str, datetime] | Omit = omit,
        email: str | Omit = omit,
        limit: int | Omit = omit,
        modified_gt: Union[str, datetime] | Omit = omit,
        nosigners: str | Omit = omit,
        offset: int | Omit = omit,
        status: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentListResponse:
        """List (unarchived) signing documents.

        Use /status/ if you need high-level
        information.

        Args:
          group: Filter by a specific group, required.

          archived: Filter on archived status, default is false

          created_gt: Filter for those documents created after a certain time

          email: Filter by signer email

          limit: Length of dataset to return. Use with offset query to iterate through results.

          modified_gt: Filter for those documents modified after a certain time

          nosigners: Add value '1' to remove signers information for a faster query

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          status: Filter on document status

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/document/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "group": group,
                        "archived": archived,
                        "created_gt": created_gt,
                        "email": email,
                        "limit": limit,
                        "modified_gt": modified_gt,
                        "nosigners": nosigners,
                        "offset": offset,
                        "status": status,
                    },
                    document_list_params.DocumentListParams,
                ),
            ),
            cast_to=DocumentListResponse,
        )

    async def archive(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete does not remove permanently but sets it with status 40 (removed) and
        archives it.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/document/{doc_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete_permanently(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Permanently deletes data and files.

        You must enable group automated deletion. We
        recommend archiveDocument.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/document/{doc_id}/delete/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def download_audit_log(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """
        Download pdf of audit log

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        extra_headers = {"Accept": "application/pdf", **(extra_headers or {})}
        return await self._get(
            f"/document/{doc_id}/auditlog/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )

    async def get_fields(
        self,
        doc_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentGetFieldsResponse:
        """
        Get document fields

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not doc_id:
            raise ValueError(f"Expected a non-empty value for `doc_id` but received {doc_id!r}")
        return await self._get(
            f"/document/{doc_id}/fields/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentGetFieldsResponse,
        )

    async def preview(
        self,
        *,
        group: str | Omit = omit,
        signee_count: int | Omit = omit,
        text: str | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Returns a redirect response (302) with link in the Location header to a one-use
        temporary URL you can redirect to, to see a preview of the signing page. Follow
        the redirect immediately since it expires after a few seconds.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/document/preview/",
            body=await async_maybe_transform(
                {
                    "group": group,
                    "signee_count": signee_count,
                    "text": text,
                    "title": title,
                },
                document_preview_params.DocumentPreviewParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class DocumentResourceWithRawResponse:
    def __init__(self, document: DocumentResource) -> None:
        self._document = document

        self.create = to_raw_response_wrapper(
            document.create,
        )
        self.retrieve = to_raw_response_wrapper(
            document.retrieve,
        )
        self.list = to_raw_response_wrapper(
            document.list,
        )
        self.archive = to_raw_response_wrapper(
            document.archive,
        )
        self.delete_permanently = to_raw_response_wrapper(
            document.delete_permanently,
        )
        self.download_audit_log = to_custom_raw_response_wrapper(
            document.download_audit_log,
            BinaryAPIResponse,
        )
        self.get_fields = to_raw_response_wrapper(
            document.get_fields,
        )
        self.preview = to_raw_response_wrapper(
            document.preview,
        )


class AsyncDocumentResourceWithRawResponse:
    def __init__(self, document: AsyncDocumentResource) -> None:
        self._document = document

        self.create = async_to_raw_response_wrapper(
            document.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            document.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            document.list,
        )
        self.archive = async_to_raw_response_wrapper(
            document.archive,
        )
        self.delete_permanently = async_to_raw_response_wrapper(
            document.delete_permanently,
        )
        self.download_audit_log = async_to_custom_raw_response_wrapper(
            document.download_audit_log,
            AsyncBinaryAPIResponse,
        )
        self.get_fields = async_to_raw_response_wrapper(
            document.get_fields,
        )
        self.preview = async_to_raw_response_wrapper(
            document.preview,
        )


class DocumentResourceWithStreamingResponse:
    def __init__(self, document: DocumentResource) -> None:
        self._document = document

        self.create = to_streamed_response_wrapper(
            document.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            document.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            document.list,
        )
        self.archive = to_streamed_response_wrapper(
            document.archive,
        )
        self.delete_permanently = to_streamed_response_wrapper(
            document.delete_permanently,
        )
        self.download_audit_log = to_custom_streamed_response_wrapper(
            document.download_audit_log,
            StreamedBinaryAPIResponse,
        )
        self.get_fields = to_streamed_response_wrapper(
            document.get_fields,
        )
        self.preview = to_streamed_response_wrapper(
            document.preview,
        )


class AsyncDocumentResourceWithStreamingResponse:
    def __init__(self, document: AsyncDocumentResource) -> None:
        self._document = document

        self.create = async_to_streamed_response_wrapper(
            document.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            document.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            document.list,
        )
        self.archive = async_to_streamed_response_wrapper(
            document.archive,
        )
        self.delete_permanently = async_to_streamed_response_wrapper(
            document.delete_permanently,
        )
        self.download_audit_log = async_to_custom_streamed_response_wrapper(
            document.download_audit_log,
            AsyncStreamedBinaryAPIResponse,
        )
        self.get_fields = async_to_streamed_response_wrapper(
            document.get_fields,
        )
        self.preview = async_to_streamed_response_wrapper(
            document.preview,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from .._models import BaseModel
from .webhook_event_filter_enum import WebhookEventFilterEnum

__all__ = ["NotificationListResponse", "NotificationListResponseItem"]


class NotificationListResponseItem(BaseModel):
    active: Optional[bool] = None

    event_filter: Optional[WebhookEventFilterEnum] = None

    group_id: Optional[int] = None

    notify_when: Optional[Literal[1, 2, 3, 4, 10]] = None
    """1 = every 6 minutes, 2 = upon signing, 3 = sent, 4 = rejected, 10 = realtime"""

    url: Optional[str] = None


NotificationListResponse: TypeAlias = List[NotificationListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .webhook_event_filter_enum import WebhookEventFilterEnum

__all__ = ["SubscribeCreateWebhookParams"]


class SubscribeCreateWebhookParams(TypedDict, total=False):
    notify: Required[str]
    """
    The type of callback to receive, value must be all, signed, sent, rejected or
    realtime
    """

    url: Required[str]
    """The URL where you wish to get notified"""

    event_filter: Annotated[WebhookEventFilterEnum, PropertyInfo(alias="eventFilter")]

    group: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["SignerRetrieveFieldsResponse", "SignerRetrieveFieldsResponseItem"]


class SignerRetrieveFieldsResponseItem(BaseModel):
    fieldorder: Optional[int] = None

    label: Optional[str] = None

    label_extra: Optional[str] = None

    state: Optional[bool] = None

    value: Optional[str] = None
    """If the field is a signer file this value will be a short lived download URL"""


SignerRetrieveFieldsResponse: TypeAlias = List[SignerRetrieveFieldsResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["DocumentCreateResponse"]


class DocumentCreateResponse(BaseModel):
    signer_1: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["DocumentCreateParams", "Signer", "SignerReviewer"]


class DocumentCreateParams(TypedDict, total=False):
    group: Required[str]

    name: Required[str]

    signers: Required[Iterable[Signer]]

    append_pdf: bool
    """Append Legalesign validation info to final PDF.

    If not included uses the group default.
    """

    auto_archive: bool
    """Send to archive soon after signing. Keeps web app clutter free"""

    cc_emails: str
    """
    Comma delimited string of email addresses that are notified of signing or
    rejection.
    """

    convert_sender_to_signer: bool
    """
    If any sender fields are left blank, convert them to fields for the first
    recipient.
    """

    do_email: bool
    """Use Legalesign email to send notification emails.

    If false suppresses all emails.
    """

    footer: str
    """Text doc only.

    The footer for the final pdf. Use keyword \"default\" to use group default
    footer.
    """

    footer_height: int
    """Text based doc only. Pixel height of PDF footer, if used. 1px = 0.025cm"""

    header: str
    """Text based doc only.

    The header for the final pdf. Use keyword \"default\" to use group header
    footer.
    """

    header_height: int
    """Text based doc only. Pixel height of final PDF footer, if used. 1px = 0.025cm"""

    pdf_password: str
    """Set a password.

    Must be ascii encode-able, you must also set signature_type to 4 and choose a
    pdf_password_type.
    """

    pdf_password_type: Literal[1, 2]
    """1 to store password, 2 for to delete from our records upon final signing."""

    pdftext: Dict[str, str]
    """Assign values to PDF sender fields, use field labels as keys.

    Requires unique fields labels. See also strict_fields.
    """

    redirect: str
    """URL to send the signer to after signing (instead of download page).

    Your URL will include query parameters with ID and state information as follows:
    YOUR-URL?signer=[signer_uid]&doc=[doc_id]&group=[group_id]&signer_state=[signer_status]&doc_state=[doc_status]
    """

    reminders: str
    """
    Put 'default' if you wish to use the default reminder schedule in the group (go
    to web app to set default schedule)
    """

    return_signer_links: bool
    """Return document links for signers in the response BODY."""

    signature_type: int
    """Use 4 to get your executed PDF Certified.

    Recommended. Defaults to 1 (uses a sha256 hash for document integrity).
    """

    signers_in_order: bool
    """Notify signers in their order sequence.

    If false all are notified simulataneously.
    """

    signertext: Dict[str, str]
    """
    Add custom placeholders to signer fields, using labels as keys in an object (as
    for pdftext). Relies on unique labelling.
    """

    strict_fields: bool
    """pdftext fails silently for invalid field value, set to true to return an error"""

    tag: str

    tag1: str

    tag2: str

    template: str
    """Resource URI of text template object.

    This call must contain either one of the attributes text, templatepdf, template.
    """

    templatepdf: str
    """Resource URI of templatepdf object.

    This API call must contain either one of the attributes text, templatepdf,
    template.
    """

    text: str
    """Raw html.

    This API call must contain either one of the attributes text, templatepdf,
    template.
    """

    user: str
    """Assign document another user in the group. Defaults to API"""


class SignerReviewer(TypedDict, total=False):
    email: Required[str]

    firstname: str

    include_link: bool
    """include a link to the signing pages enabling a reviewer to signer"""

    lastname: str


class Signer(TypedDict, total=False):
    email: Required[str]

    firstname: Required[str]

    lastname: Required[str]

    attachments: SequenceNotStr[str]
    """List of attachment resource URIs"""

    behalfof: str
    """deprecated, do not use"""

    decide_later: bool
    """
    Add this you want the previous signer or approver to decide who the next person
    should be. Commonly used for witnesses (see \"role\"). If you use this leave all
    other attributes blank. First signer cannot use this attribute.
    """

    expires: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]
    """ISO8601 formed datetime, set to TZ of sender or timezone if used"""

    message: str
    """
    Your personal message for the party, entered in the centre of the group email
    template. Use the name of a saved email template preceeded by a hash symbol to
    use that template. If there is more than one template of the same name it will
    select the one last modified.
    """

    order: int
    """Zero-indexed signer ordering, deprecated.

    Ordering of signers/witnesses/approvers is now the natural order of your signers
    list.
    """

    reviewers: Iterable[SignerReviewer]

    role: Literal["witness", "approver"]
    """If this person is a witness use \"witness\".

    Required where a witness is defined in your PDF. If this person is a normal
    signer, use \"approver\" to switch to an approver role. Witnesses and witnessed
    signers also require \"sms\" (see also \"decide_later\").
    """

    sms: str
    """Use international format number to add SMS verification.

    Required if a witness or a witnessed signer.
    """

    subject: str
    """Subject line for outbound email"""

    timezone: str
    """
    TZ of the signer, must be valid TZ as per timezoneenum (see User for
    timezoneenum details). If blank uses tz of the sender.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["SignerResetParams"]


class SignerResetParams(TypedDict, total=False):
    email: Required[str]
    """Email of signer to revert to."""

    notify: bool
    """Email notify current signer access is being withdrawn"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel
from .list_meta import ListMeta
from .document_status_enum import DocumentStatusEnum

__all__ = ["DocumentListResponse", "Object"]


class Object(BaseModel):
    archived: Optional[bool] = None

    auto_archive: Optional[bool] = None

    cc_emails: Optional[str] = None

    created: Optional[datetime] = None

    do_email: Optional[bool] = None

    download_final: Optional[bool] = None

    group: Optional[str] = None

    modified: Optional[datetime] = None

    name: Optional[str] = None

    pdftext: Optional[str] = None

    redirect: Optional[str] = None

    resource_uri: Optional[str] = None

    return_signer_links: Optional[bool] = None

    signers: Optional[List[List[str]]] = None
    """nested arrays with signer details"""

    signers_in_order: Optional[Literal[0, 1]] = None

    status: Optional[DocumentStatusEnum] = None
    """Document status options:

    - 10 - Initial state, check signer status for sent/unsent
    - 20 - Fields completed
    - 30 - Signed
    - 40 - Removed (before signing)
    - 50 - Rejected
    """

    tag: Optional[str] = None

    tag1: Optional[str] = None

    tag2: Optional[str] = None

    template: Optional[str] = None

    templatepdf: Optional[str] = None

    text: Optional[str] = None

    user: Optional[str] = None

    uuid: Optional[str] = None


class DocumentListResponse(BaseModel):
    meta: Optional[ListMeta] = None

    objects: Optional[List[Object]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .webhook_event_filter_enum import WebhookEventFilterEnum

__all__ = ["UnsubscribeDeleteWebhookParams"]


class UnsubscribeDeleteWebhookParams(TypedDict, total=False):
    url: Required[str]
    """URL to remove, it must match any registered callback exactly"""

    event_filter: Annotated[WebhookEventFilterEnum, PropertyInfo(alias="eventFilter")]

    group: int
    """if a group filter is applied refer to it with slug or resource_uri"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel
from .document_status_enum import DocumentStatusEnum

__all__ = ["DocumentRetrieveResponse"]


class DocumentRetrieveResponse(BaseModel):
    archived: Optional[bool] = None

    auto_archive: Optional[bool] = None
    """Send document archive very soon after signing."""

    cc_emails: Optional[str] = None
    """who will be cc'd with sender on email notification when signed"""

    created: Optional[datetime] = None

    do_email: Optional[bool] = None

    download_final: Optional[bool] = None
    """Final PDF is available to download"""

    footer: Optional[str] = None
    """HTML docs - text for footer if used"""

    footer_height: Optional[int] = None
    """HTMl docs - px height of footer if used"""

    group: Optional[str] = None
    """Resource URI of group"""

    has_fields: Optional[bool] = None

    hash_value: Optional[str] = None
    """SHA256 checksum of final doc, use this to validate your final PDF download"""

    header: Optional[str] = None
    """HTML docs - text for header if used"""

    header_height: Optional[int] = None
    """HTMl docs - px height of header if used"""

    modified: Optional[datetime] = None

    name: Optional[str] = None

    pdf_password: Optional[str] = None
    """PDF password if used and if save-able"""

    pdf_password_type: Optional[str] = None
    """how pdf password is retained"""

    pdftext: Optional[str] = None
    """ignore this"""

    redirect: Optional[str] = None
    """url for signer redirect after signing"""

    resource_uri: Optional[str] = None

    return_signer_links: Optional[bool] = None
    """ignore"""

    sign_mouse: Optional[bool] = None
    """legacy"""

    sign_time: Optional[datetime] = None

    sign_type: Optional[bool] = None
    """legacy"""

    sign_upload: Optional[bool] = None
    """legacy"""

    signature_placement: Optional[int] = None
    """legacy"""

    signature_type: Optional[int] = None
    """legacy - always 4"""

    signers: Optional[List[List[str]]] = None
    """nested arrays with signer details"""

    signers_in_order: Optional[bool] = None

    status: Optional[DocumentStatusEnum] = None
    """Document status options:

    - 10 - Initial state, check signer status for sent/unsent
    - 20 - Fields completed
    - 30 - Signed
    - 40 - Removed (before signing)
    - 50 - Rejected
    """

    tag: Optional[str] = None
    """your reference"""

    tag1: Optional[str] = None
    """your reference"""

    tag2: Optional[str] = None
    """your reference"""

    template: Optional[str] = None

    templatepdf: Optional[str] = None

    text: Optional[str] = None

    user: Optional[str] = None
    """Resource URI of user"""

    uuid: Optional[str] = None
    """Object ID alone"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import invited_list_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.invited_list_response import InvitedListResponse

__all__ = ["InvitedResource", "AsyncInvitedResource"]


class InvitedResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> InvitedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return InvitedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> InvitedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return InvitedResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        group: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InvitedListResponse:
        """
        Invitations to people to join the group are listed by email

        Args:
          group: filter list by a given group

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/invited/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"group": group}, invited_list_params.InvitedListParams),
            ),
            cast_to=InvitedListResponse,
        )

    def delete(
        self,
        invited_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete invitation

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not invited_id:
            raise ValueError(f"Expected a non-empty value for `invited_id` but received {invited_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/invited/{invited_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncInvitedResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncInvitedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncInvitedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncInvitedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncInvitedResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        group: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> InvitedListResponse:
        """
        Invitations to people to join the group are listed by email

        Args:
          group: filter list by a given group

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/invited/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"group": group}, invited_list_params.InvitedListParams),
            ),
            cast_to=InvitedListResponse,
        )

    async def delete(
        self,
        invited_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete invitation

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not invited_id:
            raise ValueError(f"Expected a non-empty value for `invited_id` but received {invited_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/invited/{invited_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class InvitedResourceWithRawResponse:
    def __init__(self, invited: InvitedResource) -> None:
        self._invited = invited

        self.list = to_raw_response_wrapper(
            invited.list,
        )
        self.delete = to_raw_response_wrapper(
            invited.delete,
        )


class AsyncInvitedResourceWithRawResponse:
    def __init__(self, invited: AsyncInvitedResource) -> None:
        self._invited = invited

        self.list = async_to_raw_response_wrapper(
            invited.list,
        )
        self.delete = async_to_raw_response_wrapper(
            invited.delete,
        )


class InvitedResourceWithStreamingResponse:
    def __init__(self, invited: InvitedResource) -> None:
        self._invited = invited

        self.list = to_streamed_response_wrapper(
            invited.list,
        )
        self.delete = to_streamed_response_wrapper(
            invited.delete,
        )


class AsyncInvitedResourceWithStreamingResponse:
    def __init__(self, invited: AsyncInvitedResource) -> None:
        self._invited = invited

        self.list = async_to_streamed_response_wrapper(
            invited.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            invited.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from .timezone_enum import TimezoneEnum

__all__ = ["UserCreateParams"]


class UserCreateParams(TypedDict, total=False):
    email: Required[str]

    first_name: Required[str]

    last_name: Required[str]

    groups: str
    """
    comma delimited list of groups to add user to, can be full group resource_uri or
    groupId
    """

    password: str
    """If not set a verification email is sent.

    Password must be at least 8 chars, include upper and lower case, with a number
    and a special character
    """

    permission: Literal["1", "2", "3", "4", "5", "6"]
    """
    set user permissions _ 1 - admin _ 2 - create and send docs, team user _ 3 -
    readonly, team user _ 4 - send only, team user _ 5 - send only, individual user
    _ 6 - create and send docs, invidual user
    """

    timezone: TimezoneEnum
    """List of available timezones"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union

import httpx

from .fields import (
    FieldsResource,
    AsyncFieldsResource,
    FieldsResourceWithRawResponse,
    AsyncFieldsResourceWithRawResponse,
    FieldsResourceWithStreamingResponse,
    AsyncFieldsResourceWithStreamingResponse,
)
from ...types import templatepdf_list_params, templatepdf_create_params
from ..._types import Body, Omit, Query, Headers, NoneType, NotGiven, Base64FileInput, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.template_pdf import TemplatePdf
from ...types.templatepdf_list_response import TemplatepdfListResponse

__all__ = ["TemplatepdfResource", "AsyncTemplatepdfResource"]


class TemplatepdfResource(SyncAPIResource):
    @cached_property
    def fields(self) -> FieldsResource:
        return FieldsResource(self._client)

    @cached_property
    def with_raw_response(self) -> TemplatepdfResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return TemplatepdfResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TemplatepdfResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return TemplatepdfResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        group: str,
        pdf_file: Union[str, Base64FileInput],
        archive_upon_send: bool | Omit = omit,
        process_tags: bool | Omit = omit,
        title: str | Omit = omit,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Upload a PDF document you want to send to be signed

        Args:
          pdf_file: base64 encoded PDF file data

          archive_upon_send: archive PDF when sent

          user: assign to group member if not api user

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/templatepdf/",
            body=maybe_transform(
                {
                    "group": group,
                    "pdf_file": pdf_file,
                    "archive_upon_send": archive_upon_send,
                    "process_tags": process_tags,
                    "title": title,
                    "user": user,
                },
                templatepdf_create_params.TemplatepdfCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplatePdf:
        """
        Get PDF template

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        return self._get(
            f"/templatepdf/{pdf_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplatePdf,
        )

    def list(
        self,
        *,
        archive: str | Omit = omit,
        group: str | Omit = omit,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplatepdfListResponse:
        """
        Get PDF templates

        Args:
          group: can be full resource_uri or only id

          limit: Length of dataset to return. Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/templatepdf/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "archive": archive,
                        "group": group,
                        "limit": limit,
                        "offset": offset,
                    },
                    templatepdf_list_params.TemplatepdfListParams,
                ),
            ),
            cast_to=TemplatepdfListResponse,
        )

    def archive(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delists the PDF

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/templatepdf/{pdf_id}/archive/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def convert_tags(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Convert any text tags in the PDF into fields

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/templatepdf/{pdf_id}/tags/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_edit_link(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Get PDF embeddable link

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        return self._get(
            f"/templatepdf/{pdf_id}/edit-link/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class AsyncTemplatepdfResource(AsyncAPIResource):
    @cached_property
    def fields(self) -> AsyncFieldsResource:
        return AsyncFieldsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncTemplatepdfResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTemplatepdfResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTemplatepdfResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncTemplatepdfResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        group: str,
        pdf_file: Union[str, Base64FileInput],
        archive_upon_send: bool | Omit = omit,
        process_tags: bool | Omit = omit,
        title: str | Omit = omit,
        user: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Upload a PDF document you want to send to be signed

        Args:
          pdf_file: base64 encoded PDF file data

          archive_upon_send: archive PDF when sent

          user: assign to group member if not api user

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/templatepdf/",
            body=await async_maybe_transform(
                {
                    "group": group,
                    "pdf_file": pdf_file,
                    "archive_upon_send": archive_upon_send,
                    "process_tags": process_tags,
                    "title": title,
                    "user": user,
                },
                templatepdf_create_params.TemplatepdfCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplatePdf:
        """
        Get PDF template

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        return await self._get(
            f"/templatepdf/{pdf_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplatePdf,
        )

    async def list(
        self,
        *,
        archive: str | Omit = omit,
        group: str | Omit = omit,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplatepdfListResponse:
        """
        Get PDF templates

        Args:
          group: can be full resource_uri or only id

          limit: Length of dataset to return. Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/templatepdf/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "archive": archive,
                        "group": group,
                        "limit": limit,
                        "offset": offset,
                    },
                    templatepdf_list_params.TemplatepdfListParams,
                ),
            ),
            cast_to=TemplatepdfListResponse,
        )

    async def archive(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delists the PDF

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/templatepdf/{pdf_id}/archive/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def convert_tags(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Convert any text tags in the PDF into fields

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/templatepdf/{pdf_id}/tags/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_edit_link(
        self,
        pdf_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Get PDF embeddable link

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pdf_id:
            raise ValueError(f"Expected a non-empty value for `pdf_id` but received {pdf_id!r}")
        return await self._get(
            f"/templatepdf/{pdf_id}/edit-link/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class TemplatepdfResourceWithRawResponse:
    def __init__(self, templatepdf: TemplatepdfResource) -> None:
        self._templatepdf = templatepdf

        self.create = to_raw_response_wrapper(
            templatepdf.create,
        )
        self.retrieve = to_raw_response_wrapper(
            templatepdf.retrieve,
        )
        self.list = to_raw_response_wrapper(
            templatepdf.list,
        )
        self.archive = to_raw_response_wrapper(
            templatepdf.archive,
        )
        self.convert_tags = to_raw_response_wrapper(
            templatepdf.convert_tags,
        )
        self.get_edit_link = to_raw_response_wrapper(
            templatepdf.get_edit_link,
        )

    @cached_property
    def fields(self) -> FieldsResourceWithRawResponse:
        return FieldsResourceWithRawResponse(self._templatepdf.fields)


class AsyncTemplatepdfResourceWithRawResponse:
    def __init__(self, templatepdf: AsyncTemplatepdfResource) -> None:
        self._templatepdf = templatepdf

        self.create = async_to_raw_response_wrapper(
            templatepdf.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            templatepdf.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            templatepdf.list,
        )
        self.archive = async_to_raw_response_wrapper(
            templatepdf.archive,
        )
        self.convert_tags = async_to_raw_response_wrapper(
            templatepdf.convert_tags,
        )
        self.get_edit_link = async_to_raw_response_wrapper(
            templatepdf.get_edit_link,
        )

    @cached_property
    def fields(self) -> AsyncFieldsResourceWithRawResponse:
        return AsyncFieldsResourceWithRawResponse(self._templatepdf.fields)


class TemplatepdfResourceWithStreamingResponse:
    def __init__(self, templatepdf: TemplatepdfResource) -> None:
        self._templatepdf = templatepdf

        self.create = to_streamed_response_wrapper(
            templatepdf.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            templatepdf.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            templatepdf.list,
        )
        self.archive = to_streamed_response_wrapper(
            templatepdf.archive,
        )
        self.convert_tags = to_streamed_response_wrapper(
            templatepdf.convert_tags,
        )
        self.get_edit_link = to_streamed_response_wrapper(
            templatepdf.get_edit_link,
        )

    @cached_property
    def fields(self) -> FieldsResourceWithStreamingResponse:
        return FieldsResourceWithStreamingResponse(self._templatepdf.fields)


class AsyncTemplatepdfResourceWithStreamingResponse:
    def __init__(self, templatepdf: AsyncTemplatepdfResource) -> None:
        self._templatepdf = templatepdf

        self.create = async_to_streamed_response_wrapper(
            templatepdf.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            templatepdf.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            templatepdf.list,
        )
        self.archive = async_to_streamed_response_wrapper(
            templatepdf.archive,
        )
        self.convert_tags = async_to_streamed_response_wrapper(
            templatepdf.convert_tags,
        )
        self.get_edit_link = async_to_streamed_response_wrapper(
            templatepdf.get_edit_link,
        )

    @cached_property
    def fields(self) -> AsyncFieldsResourceWithStreamingResponse:
        return AsyncFieldsResourceWithStreamingResponse(self._templatepdf.fields)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["SignerGetRejectionReasonResponse"]


class SignerGetRejectionReasonResponse(BaseModel):
    reason: Optional[str] = None

    status: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["DocumentStatusEnum"]

DocumentStatusEnum: TypeAlias = Literal[10, 20, 30, 40, 50]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import group_list_params, group_create_params, group_update_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.group_list_response import GroupListResponse
from ..types.group_retrieve_response import GroupRetrieveResponse

__all__ = ["GroupResource", "AsyncGroupResource"]


class GroupResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GroupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return GroupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GroupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return GroupResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        xframe_allow: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create group

        Args:
          xframe_allow: Set to true if you want to embed your signing page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/group/",
            body=maybe_transform(
                {
                    "name": name,
                    "xframe_allow": xframe_allow,
                },
                group_create_params.GroupCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve(
        self,
        group_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GroupRetrieveResponse:
        """
        Get group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return self._get(
            f"/group/{group_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GroupRetrieveResponse,
        )

    def update(
        self,
        group_id: str,
        *,
        public_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/group/{group_id}/",
            body=maybe_transform({"public_name": public_name}, group_update_params.GroupUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GroupListResponse:
        """List groups the api user belongs to

        Args:
          limit: Length of dataset to return.

        Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/group/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                    },
                    group_list_params.GroupListParams,
                ),
            ),
            cast_to=GroupListResponse,
        )


class AsyncGroupResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGroupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncGroupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGroupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncGroupResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        xframe_allow: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create group

        Args:
          xframe_allow: Set to true if you want to embed your signing page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/group/",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "xframe_allow": xframe_allow,
                },
                group_create_params.GroupCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve(
        self,
        group_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GroupRetrieveResponse:
        """
        Get group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        return await self._get(
            f"/group/{group_id}/",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GroupRetrieveResponse,
        )

    async def update(
        self,
        group_id: str,
        *,
        public_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not group_id:
            raise ValueError(f"Expected a non-empty value for `group_id` but received {group_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/group/{group_id}/",
            body=await async_maybe_transform({"public_name": public_name}, group_update_params.GroupUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def list(
        self,
        *,
        limit: int | Omit = omit,
        offset: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> GroupListResponse:
        """List groups the api user belongs to

        Args:
          limit: Length of dataset to return.

        Use with offset query to iterate through results.

          offset: Offset from start of dataset. Use with the limit query to iterate through
              dataset.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/group/",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "offset": offset,
                    },
                    group_list_params.GroupListParams,
                ),
            ),
            cast_to=GroupListResponse,
        )


class GroupResourceWithRawResponse:
    def __init__(self, group: GroupResource) -> None:
        self._group = group

        self.create = to_raw_response_wrapper(
            group.create,
        )
        self.retrieve = to_raw_response_wrapper(
            group.retrieve,
        )
        self.update = to_raw_response_wrapper(
            group.update,
        )
        self.list = to_raw_response_wrapper(
            group.list,
        )


class AsyncGroupResourceWithRawResponse:
    def __init__(self, group: AsyncGroupResource) -> None:
        self._group = group

        self.create = async_to_raw_response_wrapper(
            group.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            group.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            group.update,
        )
        self.list = async_to_raw_response_wrapper(
            group.list,
        )


class GroupResourceWithStreamingResponse:
    def __init__(self, group: GroupResource) -> None:
        self._group = group

        self.create = to_streamed_response_wrapper(
            group.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            group.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            group.update,
        )
        self.list = to_streamed_response_wrapper(
            group.list,
        )


class AsyncGroupResourceWithStreamingResponse:
    def __init__(self, group: AsyncGroupResource) -> None:
        self._group = group

        self.create = async_to_streamed_response_wrapper(
            group.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            group.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            group.update,
        )
        self.list = async_to_streamed_response_wrapper(
            group.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["SignerStatusEnum"]

SignerStatusEnum: TypeAlias = Literal[4, 5, 10, 15, 20, 30, 35, 39, 40, 50, 60]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["SignerSendReminderParams"]


class SignerSendReminderParams(TypedDict, total=False):
    text: str
    """custom message text, html will be stripped"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import WebhookEventFilterEnum, subscribe_create_webhook_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.webhook_event_filter_enum import WebhookEventFilterEnum

__all__ = ["SubscribeResource", "AsyncSubscribeResource"]


class SubscribeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SubscribeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return SubscribeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SubscribeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return SubscribeResourceWithStreamingResponse(self)

    def create_webhook(
        self,
        *,
        notify: str,
        url: str,
        event_filter: WebhookEventFilterEnum | Omit = omit,
        group: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create webhook

        Args:
          notify: The type of callback to receive, value must be all, signed, sent, rejected or
              realtime

          url: The URL where you wish to get notified

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/subscribe/",
            body=maybe_transform(
                {
                    "notify": notify,
                    "url": url,
                    "event_filter": event_filter,
                    "group": group,
                },
                subscribe_create_webhook_params.SubscribeCreateWebhookParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncSubscribeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSubscribeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSubscribeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSubscribeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/legalesign/legalesign-rest-python#with_streaming_response
        """
        return AsyncSubscribeResourceWithStreamingResponse(self)

    async def create_webhook(
        self,
        *,
        notify: str,
        url: str,
        event_filter: WebhookEventFilterEnum | Omit = omit,
        group: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Create webhook

        Args:
          notify: The type of callback to receive, value must be all, signed, sent, rejected or
              realtime

          url: The URL where you wish to get notified

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/subscribe/",
            body=await async_maybe_transform(
                {
                    "notify": notify,
                    "url": url,
                    "event_filter": event_filter,
                    "group": group,
                },
                subscribe_create_webhook_params.SubscribeCreateWebhookParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class SubscribeResourceWithRawResponse:
    def __init__(self, subscribe: SubscribeResource) -> None:
        self._subscribe = subscribe

        self.create_webhook = to_raw_response_wrapper(
            subscribe.create_webhook,
        )


class AsyncSubscribeResourceWithRawResponse:
    def __init__(self, subscribe: AsyncSubscribeResource) -> None:
        self._subscribe = subscribe

        self.create_webhook = async_to_raw_response_wrapper(
            subscribe.create_webhook,
        )


class SubscribeResourceWithStreamingResponse:
    def __init__(self, subscribe: SubscribeResource) -> None:
        self._subscribe = subscribe

        self.create_webhook = to_streamed_response_wrapper(
            subscribe.create_webhook,
        )


class AsyncSubscribeResourceWithStreamingResponse:
    def __init__(self, subscribe: AsyncSubscribeResource) -> None:
        self._subscribe = subscribe

        self.create_webhook = async_to_streamed_response_wrapper(
            subscribe.create_webhook,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["PermissionsEnum"]

PermissionsEnum: TypeAlias = Literal[1, 2, 3, 4, 5, 6]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel
from .list_meta import ListMeta

__all__ = ["InvitedListResponse", "Object"]


class Object(BaseModel):
    created: Optional[datetime] = None

    email: Optional[str] = None

    group: Optional[str] = None

    resource_uri: Optional[str] = None


class InvitedListResponse(BaseModel):
    meta: Optional[ListMeta] = None

    objects: Optional[List[Object]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["DocumentListParams"]


class DocumentListParams(TypedDict, total=False):
    group: Required[str]
    """Filter by a specific group, required."""

    archived: str
    """Filter on archived status, default is false"""

    created_gt: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Filter for those documents created after a certain time"""

    email: str
    """Filter by signer email"""

    limit: int
    """Length of dataset to return. Use with offset query to iterate through results."""

    modified_gt: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Filter for those documents modified after a certain time"""

    nosigners: str
    """Add value '1' to remove signers information for a faster query"""

    offset: int
    """Offset from start of dataset.

    Use with the limit query to iterate through dataset.
    """

    status: int
    """Filter on document status"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .pdf import (
    PdfResource,
    AsyncPdfResource,
    PdfResourceWithRawResponse,
    AsyncPdfResourceWithRawResponse,
    PdfResourceWithStreamingResponse,
    AsyncPdfResourceWithStreamingResponse,
)
from .user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)
from .group import (
    GroupResource,
    AsyncGroupResource,
    GroupResourceWithRawResponse,
    AsyncGroupResourceWithRawResponse,
    GroupResourceWithStreamingResponse,
    AsyncGroupResourceWithStreamingResponse,
)
from .member import (
    MemberResource,
    AsyncMemberResource,
    MemberResourceWithRawResponse,
    AsyncMemberResourceWithRawResponse,
    MemberResourceWithStreamingResponse,
    AsyncMemberResourceWithStreamingResponse,
)
from .signer import (
    SignerResource,
    AsyncSignerResource,
    SignerResourceWithRawResponse,
    AsyncSignerResourceWithRawResponse,
    SignerResourceWithStreamingResponse,
    AsyncSignerResourceWithStreamingResponse,
)
from .status import (
    StatusResource,
    AsyncStatusResource,
    StatusResourceWithRawResponse,
    AsyncStatusResourceWithRawResponse,
    StatusResourceWithStreamingResponse,
    AsyncStatusResourceWithStreamingResponse,
)
from .invited import (
    InvitedResource,
    AsyncInvitedResource,
    InvitedResourceWithRawResponse,
    AsyncInvitedResourceWithRawResponse,
    InvitedResourceWithStreamingResponse,
    AsyncInvitedResourceWithStreamingResponse,
)
from .document import (
    DocumentResource,
    AsyncDocumentResource,
    DocumentResourceWithRawResponse,
    AsyncDocumentResourceWithRawResponse,
    DocumentResourceWithStreamingResponse,
    AsyncDocumentResourceWithStreamingResponse,
)
from .template import (
    TemplateResource,
    AsyncTemplateResource,
    TemplateResourceWithRawResponse,
    AsyncTemplateResourceWithRawResponse,
    TemplateResourceWithStreamingResponse,
    AsyncTemplateResourceWithStreamingResponse,
)
from .subscribe import (
    SubscribeResource,
    AsyncSubscribeResource,
    SubscribeResourceWithRawResponse,
    AsyncSubscribeResourceWithRawResponse,
    SubscribeResourceWithStreamingResponse,
    AsyncSubscribeResourceWithStreamingResponse,
)
from .attachment import (
    AttachmentResource,
    AsyncAttachmentResource,
    AttachmentResourceWithRawResponse,
    AsyncAttachmentResourceWithRawResponse,
    AttachmentResourceWithStreamingResponse,
    AsyncAttachmentResourceWithStreamingResponse,
)
from .templatepdf import (
    TemplatepdfResource,
    AsyncTemplatepdfResource,
    TemplatepdfResourceWithRawResponse,
    AsyncTemplatepdfResourceWithRawResponse,
    TemplatepdfResourceWithStreamingResponse,
    AsyncTemplatepdfResourceWithStreamingResponse,
)
from .unsubscribe import (
    UnsubscribeResource,
    AsyncUnsubscribeResource,
    UnsubscribeResourceWithRawResponse,
    AsyncUnsubscribeResourceWithRawResponse,
    UnsubscribeResourceWithStreamingResponse,
    AsyncUnsubscribeResourceWithStreamingResponse,
)
from .notifications import (
    NotificationsResource,
    AsyncNotificationsResource,
    NotificationsResourceWithRawResponse,
    AsyncNotificationsResourceWithRawResponse,
    NotificationsResourceWithStreamingResponse,
    AsyncNotificationsResourceWithStreamingResponse,
)

__all__ = [
    "AttachmentResource",
    "AsyncAttachmentResource",
    "AttachmentResourceWithRawResponse",
    "AsyncAttachmentResourceWithRawResponse",
    "AttachmentResourceWithStreamingResponse",
    "AsyncAttachmentResourceWithStreamingResponse",
    "DocumentResource",
    "AsyncDocumentResource",
    "DocumentResourceWithRawResponse",
    "AsyncDocumentResourceWithRawResponse",
    "DocumentResourceWithStreamingResponse",
    "AsyncDocumentResourceWithStreamingResponse",
    "GroupResource",
    "AsyncGroupResource",
    "GroupResourceWithRawResponse",
    "AsyncGroupResourceWithRawResponse",
    "GroupResourceWithStreamingResponse",
    "AsyncGroupResourceWithStreamingResponse",
    "InvitedResource",
    "AsyncInvitedResource",
    "InvitedResourceWithRawResponse",
    "AsyncInvitedResourceWithRawResponse",
    "InvitedResourceWithStreamingResponse",
    "AsyncInvitedResourceWithStreamingResponse",
    "MemberResource",
    "AsyncMemberResource",
    "MemberResourceWithRawResponse",
    "AsyncMemberResourceWithRawResponse",
    "MemberResourceWithStreamingResponse",
    "AsyncMemberResourceWithStreamingResponse",
    "NotificationsResource",
    "AsyncNotificationsResource",
    "NotificationsResourceWithRawResponse",
    "AsyncNotificationsResourceWithRawResponse",
    "NotificationsResourceWithStreamingResponse",
    "AsyncNotificationsResourceWithStreamingResponse",
    "PdfResource",
    "AsyncPdfResource",
    "PdfResourceWithRawResponse",
    "AsyncPdfResourceWithRawResponse",
    "PdfResourceWithStreamingResponse",
    "AsyncPdfResourceWithStreamingResponse",
    "SignerResource",
    "AsyncSignerResource",
    "SignerResourceWithRawResponse",
    "AsyncSignerResourceWithRawResponse",
    "SignerResourceWithStreamingResponse",
    "AsyncSignerResourceWithStreamingResponse",
    "StatusResource",
    "AsyncStatusResource",
    "StatusResourceWithRawResponse",
    "AsyncStatusResourceWithRawResponse",
    "StatusResourceWithStreamingResponse",
    "AsyncStatusResourceWithStreamingResponse",
    "SubscribeResource",
    "AsyncSubscribeResource",
    "SubscribeResourceWithRawResponse",
    "AsyncSubscribeResourceWithRawResponse",
    "SubscribeResourceWithStreamingResponse",
    "AsyncSubscribeResourceWithStreamingResponse",
    "TemplateResource",
    "AsyncTemplateResource",
    "TemplateResourceWithRawResponse",
    "AsyncTemplateResourceWithRawResponse",
    "TemplateResourceWithStreamingResponse",
    "AsyncTemplateResourceWithStreamingResponse",
    "TemplatepdfResource",
    "AsyncTemplatepdfResource",
    "TemplatepdfResourceWithRawResponse",
    "AsyncTemplatepdfResourceWithRawResponse",
    "TemplatepdfResourceWithStreamingResponse",
    "AsyncTemplatepdfResourceWithStreamingResponse",
    "UnsubscribeResource",
    "AsyncUnsubscribeResource",
    "UnsubscribeResourceWithRawResponse",
    "AsyncUnsubscribeResourceWithRawResponse",
    "UnsubscribeResourceWithStreamingResponse",
    "AsyncUnsubscribeResourceWithStreamingResponse",
    "UserResource",
    "AsyncUserResource",
    "UserResourceWithRawResponse",
    "AsyncUserResourceWithRawResponse",
    "UserResourceWithStreamingResponse",
    "AsyncUserResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from legalesign import Legalesign, AsyncLegalesign
from tests.utils import assert_matches_type
from legalesign.types import (
    SignerRetrieveResponse,
    SignerRetrieveFieldsResponse,
    SignerGetRejectionReasonResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSigner:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Legalesign) -> None:
        signer = client.signer.retrieve(
            "signerId",
        )
        assert_matches_type(SignerRetrieveResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Legalesign) -> None:
        response = client.signer.with_raw_response.retrieve(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = response.parse()
        assert_matches_type(SignerRetrieveResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Legalesign) -> None:
        with client.signer.with_streaming_response.retrieve(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = response.parse()
            assert_matches_type(SignerRetrieveResponse, signer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Legalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            client.signer.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_access_link(self, client: Legalesign) -> None:
        signer = client.signer.get_access_link(
            "signerId",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_access_link(self, client: Legalesign) -> None:
        response = client.signer.with_raw_response.get_access_link(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = response.parse()
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_access_link(self, client: Legalesign) -> None:
        with client.signer.with_streaming_response.get_access_link(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = response.parse()
            assert signer is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_access_link(self, client: Legalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            client.signer.with_raw_response.get_access_link(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_get_rejection_reason(self, client: Legalesign) -> None:
        signer = client.signer.get_rejection_reason(
            "signerId",
        )
        assert_matches_type(SignerGetRejectionReasonResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_get_rejection_reason(self, client: Legalesign) -> None:
        response = client.signer.with_raw_response.get_rejection_reason(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = response.parse()
        assert_matches_type(SignerGetRejectionReasonResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_get_rejection_reason(self, client: Legalesign) -> None:
        with client.signer.with_streaming_response.get_rejection_reason(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = response.parse()
            assert_matches_type(SignerGetRejectionReasonResponse, signer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_get_rejection_reason(self, client: Legalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            client.signer.with_raw_response.get_rejection_reason(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_reset(self, client: Legalesign) -> None:
        signer = client.signer.reset(
            signer_id="signerId",
            email="email",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_reset_with_all_params(self, client: Legalesign) -> None:
        signer = client.signer.reset(
            signer_id="signerId",
            email="email",
            notify=True,
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_reset(self, client: Legalesign) -> None:
        response = client.signer.with_raw_response.reset(
            signer_id="signerId",
            email="email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = response.parse()
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_reset(self, client: Legalesign) -> None:
        with client.signer.with_streaming_response.reset(
            signer_id="signerId",
            email="email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = response.parse()
            assert signer is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_reset(self, client: Legalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            client.signer.with_raw_response.reset(
                signer_id="",
                email="email",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_fields(self, client: Legalesign) -> None:
        signer = client.signer.retrieve_fields(
            "signerId",
        )
        assert_matches_type(SignerRetrieveFieldsResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_fields(self, client: Legalesign) -> None:
        response = client.signer.with_raw_response.retrieve_fields(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = response.parse()
        assert_matches_type(SignerRetrieveFieldsResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_fields(self, client: Legalesign) -> None:
        with client.signer.with_streaming_response.retrieve_fields(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = response.parse()
            assert_matches_type(SignerRetrieveFieldsResponse, signer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve_fields(self, client: Legalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            client.signer.with_raw_response.retrieve_fields(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_send_reminder(self, client: Legalesign) -> None:
        signer = client.signer.send_reminder(
            signer_id="signerId",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_send_reminder_with_all_params(self, client: Legalesign) -> None:
        signer = client.signer.send_reminder(
            signer_id="signerId",
            text="text",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_send_reminder(self, client: Legalesign) -> None:
        response = client.signer.with_raw_response.send_reminder(
            signer_id="signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = response.parse()
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_send_reminder(self, client: Legalesign) -> None:
        with client.signer.with_streaming_response.send_reminder(
            signer_id="signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = response.parse()
            assert signer is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_send_reminder(self, client: Legalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            client.signer.with_raw_response.send_reminder(
                signer_id="",
            )


class TestAsyncSigner:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.retrieve(
            "signerId",
        )
        assert_matches_type(SignerRetrieveResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncLegalesign) -> None:
        response = await async_client.signer.with_raw_response.retrieve(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = await response.parse()
        assert_matches_type(SignerRetrieveResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncLegalesign) -> None:
        async with async_client.signer.with_streaming_response.retrieve(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = await response.parse()
            assert_matches_type(SignerRetrieveResponse, signer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncLegalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            await async_client.signer.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_access_link(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.get_access_link(
            "signerId",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_access_link(self, async_client: AsyncLegalesign) -> None:
        response = await async_client.signer.with_raw_response.get_access_link(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = await response.parse()
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_access_link(self, async_client: AsyncLegalesign) -> None:
        async with async_client.signer.with_streaming_response.get_access_link(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = await response.parse()
            assert signer is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_access_link(self, async_client: AsyncLegalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            await async_client.signer.with_raw_response.get_access_link(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_get_rejection_reason(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.get_rejection_reason(
            "signerId",
        )
        assert_matches_type(SignerGetRejectionReasonResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_get_rejection_reason(self, async_client: AsyncLegalesign) -> None:
        response = await async_client.signer.with_raw_response.get_rejection_reason(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = await response.parse()
        assert_matches_type(SignerGetRejectionReasonResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_get_rejection_reason(self, async_client: AsyncLegalesign) -> None:
        async with async_client.signer.with_streaming_response.get_rejection_reason(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = await response.parse()
            assert_matches_type(SignerGetRejectionReasonResponse, signer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_get_rejection_reason(self, async_client: AsyncLegalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            await async_client.signer.with_raw_response.get_rejection_reason(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_reset(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.reset(
            signer_id="signerId",
            email="email",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_reset_with_all_params(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.reset(
            signer_id="signerId",
            email="email",
            notify=True,
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_reset(self, async_client: AsyncLegalesign) -> None:
        response = await async_client.signer.with_raw_response.reset(
            signer_id="signerId",
            email="email",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = await response.parse()
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_reset(self, async_client: AsyncLegalesign) -> None:
        async with async_client.signer.with_streaming_response.reset(
            signer_id="signerId",
            email="email",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = await response.parse()
            assert signer is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_reset(self, async_client: AsyncLegalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            await async_client.signer.with_raw_response.reset(
                signer_id="",
                email="email",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_fields(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.retrieve_fields(
            "signerId",
        )
        assert_matches_type(SignerRetrieveFieldsResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_fields(self, async_client: AsyncLegalesign) -> None:
        response = await async_client.signer.with_raw_response.retrieve_fields(
            "signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = await response.parse()
        assert_matches_type(SignerRetrieveFieldsResponse, signer, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_fields(self, async_client: AsyncLegalesign) -> None:
        async with async_client.signer.with_streaming_response.retrieve_fields(
            "signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = await response.parse()
            assert_matches_type(SignerRetrieveFieldsResponse, signer, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve_fields(self, async_client: AsyncLegalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            await async_client.signer.with_raw_response.retrieve_fields(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_send_reminder(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.send_reminder(
            signer_id="signerId",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_send_reminder_with_all_params(self, async_client: AsyncLegalesign) -> None:
        signer = await async_client.signer.send_reminder(
            signer_id="signerId",
            text="text",
        )
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_send_reminder(self, async_client: AsyncLegalesign) -> None:
        response = await async_client.signer.with_raw_response.send_reminder(
            signer_id="signerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        signer = await response.parse()
        assert signer is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_send_reminder(self, async_client: AsyncLegalesign) -> None:
        async with async_client.signer.with_streaming_response.send_reminder(
            signer_id="signerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            signer = await response.parse()
            assert signer is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_send_reminder(self, async_client: AsyncLegalesign) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `signer_id` but received ''"):
            await async_client.signer.with_raw_response.send_reminder(
                signer_id="",
            )
